/********************************************
 * UTIA AV CR, v.v.i
 * Signal Processing Department
 * Pod Vodarenskou vezi 4
 * 182 08 Prague
 * Czech Republic
 * web: http://zs.utia.cas.cz
 * contact: sp@utia.cz
 *
 * Filename: vtc.h
 * Date: 02.12.2013
 * Author: Lukas Kohout <kohoutl@utia.cas.cz>
 * Description:
 *    Implements functions for handling Video Timing Controller
 *
 * Changelog:
 *
 *
 *
 *
 ********************************************/

#ifndef _VTC_HEADER_FILE_
#define _VTC_HEADER_FILE_

// #include <xvtc.h>
#include "xvtc.h"

#define XVTC_ERR_A_CHR_LOCK_MASK    0x00200000
#define XVTC_ERR_A_VID_LOCK_MASK    0x00100000
#define XVTC_ERR_HSYNC_LOCK_MASK    0x00080000
#define XVTC_ERR_VSYNC_LOCK_MASK    0x00040000
#define XVTC_ERR_HBLANK_LOCK_MASK   0x00020000
#define XVTC_ERR_VBLANK_LOCK_MASK   0x00010000
#define XVTX_ERR_ALL_MASK           ( XVTC_ERR_A_CHR_LOCK_MASK  | \
                                      XVTC_ERR_A_VID_LOCK_MASK  | \
                                      XVTC_ERR_HSYNC_LOCK_MASK  | \
                                      XVTC_ERR_VSYNC_LOCK_MASK  | \
                                      XVTC_ERR_HBLANK_LOCK_MASK | \
                                      XVTC_ERR_VBLANK_LOCK_MASK ) \


#define VTC_SEL_NONE      255 // not selected
#define VTC_1920x1080p60  0
#define VTC_1920x1200p50  1
#define VTC_1600x1200p50  2
#define VTC_1680x1050p60  3
#define VTC_1280x1024p60  4
#define VTC_1280x720p60   5
#define VTC_1024x768p60   6 
#define VTC_800x600p60    7 
#define VTC_640x480p60    8
#define VTC_600x800p60    9


#define VTC_RES_CNT     10

struct struct_vtc_t
{
  XVtc Vtc;
  XVtc_Config *VtcCfgPtr;
  XVtc_Signal SignalCfg;          // parameters of video signal
  XVtc_Polarity Polarity;         // used polarity
  XVtc_SourceSelect SourceSelect; // source selection setting
  unsigned int locked;
  unsigned char timing_sel;       // 0 - 1920x1080

};
typedef struct struct_vtc_t vtc_t;

struct struct_timing_t
{
  char *pName;
  unsigned int VActiveVideo;
  unsigned int VFrontPorch;
  unsigned int VSyncWidth;
  unsigned int VBackPorch;
  unsigned int VSyncPolarity;
  unsigned int VBlankPolarity;
  unsigned int HActiveVideo;
  unsigned int HFrontPorch;
  unsigned int HSyncWidth;
  unsigned int HBackPorch;
  unsigned int HSyncPolarity;
  unsigned int HBlankPolarity;
  float PClk;
};
typedef struct struct_timing_t timing_t;


unsigned int is_vtc_locked(XVtc *InstancePtr);

unsigned int get_vtc_status(XVtc *InstancePtr);
unsigned int get_vtc_error(XVtc *InstancePtr);

void vtc_reset(XVtc *InstancePtr);
void get_vtc_timing(vtc_t *InstancePtr);
void set_vtc_timing(vtc_t *InstancePtr);
void fill_vtc_timing(vtc_t *InstancePtr);


void print_vtc_timing(vtc_t *InstancePtr);


#endif /* _VTC_HEADER_FILE_*/
